Class: Aws::ControlCatalog::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ControlCatalog::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-controlcatalog/client.rb,
sig/client.rbs
Overview
An API client for ControlCatalog. To construct a client, you need to configure a :region and :credentials.
client = Aws::ControlCatalog::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _GetControlResponseSuccess, _ListCommonControlsResponseSuccess, _ListControlMappingsResponseSuccess, _ListControlsResponseSuccess, _ListDomainsResponseSuccess, _ListObjectivesResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_control(params = {}) ⇒ Types::GetControlResponse
Returns details about a specific control, most notably a list of Amazon Web Services Regions where this control is supported.
-
#list_common_controls(params = {}) ⇒ Types::ListCommonControlsResponse
Returns a paginated list of common controls from the Amazon Web Services Control Catalog.
-
#list_control_mappings(params = {}) ⇒ Types::ListControlMappingsResponse
Returns a paginated list of control mappings from the Control Catalog.
-
#list_controls(params = {}) ⇒ Types::ListControlsResponse
Returns a paginated list of all available controls in the Control Catalog library.
-
#list_domains(params = {}) ⇒ Types::ListDomainsResponse
Returns a paginated list of domains from the Control Catalog.
-
#list_objectives(params = {}) ⇒ Types::ListObjectivesResponse
Returns a paginated list of objectives from the Control Catalog.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
877 878 879 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 877 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
880 881 882 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 880 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 850 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ControlCatalog') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-controlcatalog' context[:gem_version] = '1.45.0' Seahorse::Client::Request.new(handlers, context) end |
#get_control(params = {}) ⇒ Types::GetControlResponse
Returns details about a specific control, most notably a list of
Amazon Web Services Regions where this control is supported. Input a
value for the ControlArn parameter, in ARN form. GetControl
accepts controltower or controlcatalog control ARNs as input.
Returns a controlcatalog ARN format.
In the API response, controls that have the value GLOBAL in the
Scope field do not show the DeployableRegions field, because it
does not apply. Controls that have the value REGIONAL in the Scope
field return a value for the DeployableRegions field, as shown in
the example.
98 |
# File 'sig/client.rbs', line 98
def get_control: (
|
#list_common_controls(params = {}) ⇒ Types::ListCommonControlsResponse
Returns a paginated list of common controls from the Amazon Web Services Control Catalog.
You can apply an optional filter to see common controls that have a specific objective. If you don’t provide a filter, the operation returns all common controls.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
109 |
# File 'sig/client.rbs', line 109
def list_common_controls: (
|
#list_control_mappings(params = {}) ⇒ Types::ListControlMappingsResponse
Returns a paginated list of control mappings from the Control Catalog. Control mappings show relationships between controls and other entities, such as common controls or compliance frameworks.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
128 |
# File 'sig/client.rbs', line 128
def list_control_mappings: (
|
#list_controls(params = {}) ⇒ Types::ListControlsResponse
Returns a paginated list of all available controls in the Control Catalog library. Allows you to discover available controls. The list of controls is given as structures of type controlSummary. The ARN is returned in the global controlcatalog format, as shown in the examples.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
145 |
# File 'sig/client.rbs', line 145
def list_controls: (
|
#list_domains(params = {}) ⇒ Types::ListDomainsResponse
Returns a paginated list of domains from the Control Catalog.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
164 |
# File 'sig/client.rbs', line 164
def list_domains: (
|
#list_objectives(params = {}) ⇒ Types::ListObjectivesResponse
Returns a paginated list of objectives from the Control Catalog.
You can apply an optional filter to see the objectives that belong to a specific domain. If you don’t provide a filter, the operation returns all objectives.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
176 |
# File 'sig/client.rbs', line 176
def list_objectives: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
870 871 872 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 870 def waiter_names [] end |