Class: Aws::ControlCatalog::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ControlCatalog::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-controlcatalog/client.rb
Overview
An API client for ControlCatalog. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ControlCatalog::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_control(params = {}) ⇒ Types::GetControlResponse
Returns details about a specific control, most notably a list of Amazon Web Services Regions where this control is supported.
-
#list_common_controls(params = {}) ⇒ Types::ListCommonControlsResponse
Returns a paginated list of common controls from the Amazon Web Services Control Catalog.
-
#list_control_mappings(params = {}) ⇒ Types::ListControlMappingsResponse
Returns a paginated list of control mappings from the Control Catalog.
-
#list_controls(params = {}) ⇒ Types::ListControlsResponse
Returns a paginated list of all available controls in the Control Catalog library.
-
#list_domains(params = {}) ⇒ Types::ListDomainsResponse
Returns a paginated list of domains from the Control Catalog.
-
#list_objectives(params = {}) ⇒ Types::ListObjectivesResponse
Returns a paginated list of objectives from the Control Catalog.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
877 878 879 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 877 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
880 881 882 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 880 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 850 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ControlCatalog') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-controlcatalog' context[:gem_version] = '1.44.0' Seahorse::Client::Request.new(handlers, context) end |
#get_control(params = {}) ⇒ Types::GetControlResponse
Returns details about a specific control, most notably a list of Amazon Web Services Regions where this control is supported. Input a value for the ControlArn parameter, in ARN form. ‘GetControl` accepts controltower or controlcatalog control ARNs as input. Returns a controlcatalog ARN format.
In the API response, controls that have the value ‘GLOBAL` in the `Scope` field do not show the `DeployableRegions` field, because it does not apply. Controls that have the value `REGIONAL` in the `Scope` field return a value for the `DeployableRegions` field, as shown in the example.
556 557 558 559 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 556 def get_control(params = {}, = {}) req = build_request(:get_control, params) req.send_request() end |
#list_common_controls(params = {}) ⇒ Types::ListCommonControlsResponse
Returns a paginated list of common controls from the Amazon Web Services Control Catalog.
You can apply an optional filter to see common controls that have a specific objective. If you don’t provide a filter, the operation returns all common controls.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
619 620 621 622 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 619 def list_common_controls(params = {}, = {}) req = build_request(:list_common_controls, params) req.send_request() end |
#list_control_mappings(params = {}) ⇒ Types::ListControlMappingsResponse
Returns a paginated list of control mappings from the Control Catalog. Control mappings show relationships between controls and other entities, such as common controls or compliance frameworks.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
673 674 675 676 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 673 def list_control_mappings(params = {}, = {}) req = build_request(:list_control_mappings, params) req.send_request() end |
#list_controls(params = {}) ⇒ Types::ListControlsResponse
Returns a paginated list of all available controls in the Control Catalog library. Allows you to discover available controls. The list of controls is given as structures of type controlSummary. The ARN is returned in the global controlcatalog format, as shown in the examples.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
740 741 742 743 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 740 def list_controls(params = {}, = {}) req = build_request(:list_controls, params) req.send_request() end |
#list_domains(params = {}) ⇒ Types::ListDomainsResponse
Returns a paginated list of domains from the Control Catalog.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
781 782 783 784 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 781 def list_domains(params = {}, = {}) req = build_request(:list_domains, params) req.send_request() end |
#list_objectives(params = {}) ⇒ Types::ListObjectivesResponse
Returns a paginated list of objectives from the Control Catalog.
You can apply an optional filter to see the objectives that belong to a specific domain. If you don’t provide a filter, the operation returns all objectives.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
841 842 843 844 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 841 def list_objectives(params = {}, = {}) req = build_request(:list_objectives, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
870 871 872 |
# File 'lib/aws-sdk-controlcatalog/client.rb', line 870 def waiter_names [] end |