Class: Aws::ControlCatalog::Types::ControlSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::ControlCatalog::Types::ControlSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-controlcatalog/types.rb
Overview
Overview of information about a control.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aliases ⇒ Array<String>
A list of alternative identifiers for the control.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the control.
-
#behavior ⇒ String
An enumerated type, with the following possible values:.
-
#create_time ⇒ Time
A timestamp that notes the time when the control was released (start of its life) as a governance capability in Amazon Web Services.
-
#description ⇒ String
A description of the control, as it may appear in the console.
-
#governed_providers ⇒ Array<String>
A list of providers whose resources are governed by this control.
-
#governed_resources ⇒ Array<String>
A list of resource types that are governed by this control.
-
#implementation ⇒ Types::ImplementationSummary
An object of type
ImplementationSummarythat describes how the control is implemented. -
#name ⇒ String
The display name of the control.
-
#parameter_requirement_summary ⇒ String
A summary that indicates whether the control requires parameters, accepts optional parameters, or does not support parameters.
-
#severity ⇒ String
An enumerated type, with the following possible values:.
Instance Attribute Details
#aliases ⇒ Array<String>
A list of alternative identifiers for the control. These are
human-readable designators, such as SH.S3.1. Several aliases can
refer to the same control across different Amazon Web Services
services or compliance frameworks.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-controlcatalog/types.rb', line 366 class ControlSummary < Struct.new( :arn, :aliases, :name, :description, :behavior, :severity, :parameter_requirement_summary, :implementation, :create_time, :governed_resources, :governed_providers) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the control.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-controlcatalog/types.rb', line 366 class ControlSummary < Struct.new( :arn, :aliases, :name, :description, :behavior, :severity, :parameter_requirement_summary, :implementation, :create_time, :governed_resources, :governed_providers) SENSITIVE = [] include Aws::Structure end |
#behavior ⇒ String
An enumerated type, with the following possible values:
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-controlcatalog/types.rb', line 366 class ControlSummary < Struct.new( :arn, :aliases, :name, :description, :behavior, :severity, :parameter_requirement_summary, :implementation, :create_time, :governed_resources, :governed_providers) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
A timestamp that notes the time when the control was released (start of its life) as a governance capability in Amazon Web Services.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-controlcatalog/types.rb', line 366 class ControlSummary < Struct.new( :arn, :aliases, :name, :description, :behavior, :severity, :parameter_requirement_summary, :implementation, :create_time, :governed_resources, :governed_providers) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the control, as it may appear in the console. Describes the functionality of the control.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-controlcatalog/types.rb', line 366 class ControlSummary < Struct.new( :arn, :aliases, :name, :description, :behavior, :severity, :parameter_requirement_summary, :implementation, :create_time, :governed_resources, :governed_providers) SENSITIVE = [] include Aws::Structure end |
#governed_providers ⇒ Array<String>
A list of providers whose resources are governed by this control.
For example, a value of AWS indicates that the control governs
Amazon Web Services resources.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-controlcatalog/types.rb', line 366 class ControlSummary < Struct.new( :arn, :aliases, :name, :description, :behavior, :severity, :parameter_requirement_summary, :implementation, :create_time, :governed_resources, :governed_providers) SENSITIVE = [] include Aws::Structure end |
#governed_resources ⇒ Array<String>
A list of resource types that are governed by this control. This
information helps you understand which controls can govern certain
types of resources, and conversely, which resources are affected
when the control is implemented. For Amazon Web Services controls,
the resources are represented as CloudFormation resource types. For
non-Amazon Web Services controls, the resources are represented in a
provider-specific format. If GovernedResources cannot be
represented by available resource types, it’s returned as an empty
list.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-controlcatalog/types.rb', line 366 class ControlSummary < Struct.new( :arn, :aliases, :name, :description, :behavior, :severity, :parameter_requirement_summary, :implementation, :create_time, :governed_resources, :governed_providers) SENSITIVE = [] include Aws::Structure end |
#implementation ⇒ Types::ImplementationSummary
An object of type ImplementationSummary that describes how the
control is implemented.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-controlcatalog/types.rb', line 366 class ControlSummary < Struct.new( :arn, :aliases, :name, :description, :behavior, :severity, :parameter_requirement_summary, :implementation, :create_time, :governed_resources, :governed_providers) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The display name of the control.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-controlcatalog/types.rb', line 366 class ControlSummary < Struct.new( :arn, :aliases, :name, :description, :behavior, :severity, :parameter_requirement_summary, :implementation, :create_time, :governed_resources, :governed_providers) SENSITIVE = [] include Aws::Structure end |
#parameter_requirement_summary ⇒ String
A summary that indicates whether the control requires parameters, accepts optional parameters, or does not support parameters. Use this field to determine whether you need to supply parameter values when you enable the control.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-controlcatalog/types.rb', line 366 class ControlSummary < Struct.new( :arn, :aliases, :name, :description, :behavior, :severity, :parameter_requirement_summary, :implementation, :create_time, :governed_resources, :governed_providers) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
An enumerated type, with the following possible values:
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-controlcatalog/types.rb', line 366 class ControlSummary < Struct.new( :arn, :aliases, :name, :description, :behavior, :severity, :parameter_requirement_summary, :implementation, :create_time, :governed_resources, :governed_providers) SENSITIVE = [] include Aws::Structure end |